Elementary
==========

This module implements elementary functions such as trigonometric, hyperbolic, and
sqrt, as well as functions like ``Abs``, ``Max``, ``Min`` etc.


sympy.functions.elementary.complexes
====================================

re
--

.. autoclass:: sympy.functions.elementary.complexes.re
   :members:

im
--

.. autoclass:: sympy.functions.elementary.complexes.im
   :members:

sign
----

.. autoclass:: sympy.functions.elementary.complexes.sign
   :members:

Abs
---

.. autoclass:: sympy.functions.elementary.complexes.Abs
   :members:

arg
---

.. autoclass:: sympy.functions.elementary.complexes.arg
   :members:

conjugate
---------

.. autoclass:: sympy.functions.elementary.complexes.conjugate
   :members:

polar_lift
----------

.. autoclass:: sympy.functions.elementary.complexes.polar_lift
   :members:

periodic_argument
-----------------

.. autoclass:: sympy.functions.elementary.complexes.periodic_argument
   :members:

principal_branch
-----------------

.. autoclass:: sympy.functions.elementary.complexes.principal_branch
   :members:


sympy.functions.elementary.trigonometric
========================================


.. _trionometric functions:

Trigonometric Functions
========================

sin
---

.. autoclass:: sympy.functions.elementary.trigonometric.sin

   :members:

cos
---

.. autoclass:: sympy.functions.elementary.trigonometric.cos

   :members:

tan
---

.. autoclass:: sympy.functions.elementary.trigonometric.tan

   :members:

cot
---

.. autoclass:: sympy.functions.elementary.trigonometric.cot

   :members:

sec
---

.. autoclass:: sympy.functions.elementary.trigonometric.sec

   :members:

csc
---

.. autoclass:: sympy.functions.elementary.trigonometric.csc

   :members:

sinc
----

.. autoclass:: sympy.functions.elementary.trigonometric.sinc

   :members:


Trigonometric Inverses
======================

asin
----

.. autoclass:: sympy.functions.elementary.trigonometric.asin

   :members:

acos
----

.. autoclass:: sympy.functions.elementary.trigonometric.acos

   :members:

atan
----

.. autoclass:: sympy.functions.elementary.trigonometric.atan

   :members:

acot
----

.. autoclass:: sympy.functions.elementary.trigonometric.acot

   :members:

asec
----

.. autoclass:: sympy.functions.elementary.trigonometric.asec

   :members:

acsc
----

.. autoclass:: sympy.functions.elementary.trigonometric.acsc

   :members:

atan2
-----

.. autoclass:: sympy.functions.elementary.trigonometric.atan2

   :members:


sympy.functions.elementary.hyperbolic
======================================

Hyperbolic Functions
====================


HyperbolicFunction
------------------

.. autoclass:: sympy.functions.elementary.hyperbolic.HyperbolicFunction

   :members:

sinh
----

.. autoclass:: sympy.functions.elementary.hyperbolic.sinh

   :members:

cosh
----

.. autoclass:: sympy.functions.elementary.hyperbolic.cosh

   :members:

tanh
----

.. autoclass:: sympy.functions.elementary.hyperbolic.tanh

   :members:

coth
----

.. autoclass:: sympy.functions.elementary.hyperbolic.coth

   :members:

sech
----

.. autoclass:: sympy.functions.elementary.hyperbolic.sech

   :members:

csch
----

.. autoclass:: sympy.functions.elementary.hyperbolic.csch

   :members:


Hyperbolic Inverses
===================

asinh
-----

.. autoclass:: sympy.functions.elementary.hyperbolic.asinh

   :members:

acosh
-----

.. autoclass:: sympy.functions.elementary.hyperbolic.acosh

   :members:

atanh
-----

.. autoclass:: sympy.functions.elementary.hyperbolic.atanh

   :members:

acoth
-----

.. autoclass:: sympy.functions.elementary.hyperbolic.acoth

   :members:

asech
-----

.. autoclass:: sympy.functions.elementary.hyperbolic.asech

   :members:

acsch
-----

.. autoclass:: sympy.functions.elementary.hyperbolic.acsch

   :members:

sympy.functions.elementary.integers
===================================

ceiling
-------

.. autoclass:: sympy.functions.elementary.integers.ceiling

   :members:


floor
-----

.. autoclass:: sympy.functions.elementary.integers.floor

   :members:


RoundFunction
-------------

.. autoclass:: sympy.functions.elementary.integers.RoundFunction


frac
----

.. autoclass:: sympy.functions.elementary.integers.frac

sympy.functions.elementary.exponential
======================================

exp
---

.. autoclass:: sympy.functions.elementary.exponential.exp

   :members:

LambertW
--------

.. autoclass:: sympy.functions.elementary.exponential.LambertW

   :members:

log
---

.. autoclass:: sympy.functions.elementary.exponential.log

   :members:


exp_polar
---------

.. autoclass:: sympy.functions.elementary.exponential.exp_polar

   :members:


sympy.functions.elementary.piecewise
====================================

ExprCondPair
------------

.. autoclass:: sympy.functions.elementary.piecewise.ExprCondPair

   :members:


Piecewise
---------

.. autoclass:: sympy.functions.elementary.piecewise.Piecewise

   :members:

.. autofunction:: sympy.functions.elementary.piecewise.piecewise_fold


sympy.functions.elementary.miscellaneous
========================================

IdentityFunction
----------------

.. autoclass:: sympy.functions.elementary.miscellaneous.IdentityFunction

   :members:

Min
---

.. autoclass:: sympy.functions.elementary.miscellaneous.Min

   :members:


Max
---

.. autoclass:: sympy.functions.elementary.miscellaneous.Max

   :members:

root
----

.. autofunction:: sympy.functions.elementary.miscellaneous.root


sqrt
----

.. autofunction:: sympy.functions.elementary.miscellaneous.sqrt


cbrt
----

.. autofunction:: sympy.functions.elementary.miscellaneous.cbrt


real_root
---------

.. autofunction:: sympy.functions.elementary.miscellaneous.real_root
